@@ -7,18 +7,18 @@ import shutil
 from typing import Generator
 from typing import Sequence
 
+from pre_commit import lang_base
 from pre_commit.envcontext import envcontext
 from pre_commit.envcontext import PatchesT
 from pre_commit.envcontext import UNSET
-from pre_commit.languages import helpers
 from pre_commit.prefix import Prefix
 from pre_commit.util import cmd_output_b
 from pre_commit.util import win_exe
 
 ENVIRONMENT_DIR = 'renv'
 RSCRIPT_OPTS = ('--no-save', '--no-restore', '--no-site-file', '--no-environ')
-get_default_version = helpers.basic_get_default_version
-health_check = helpers.basic_health_check
+get_default_version = lang_base.basic_get_default_version
+health_check = lang_base.basic_health_check
 
 
 def get_env_patch(venv: str) -> PatchesT:
@@ -30,13 +30,18 @@ def get_env_patch(venv: str) -> PatchesT:
 
 @contextlib.contextmanager
 def in_env(prefix: Prefix, version: str) -> Generator[None, None, None]:
-    envdir = helpers.environment_dir(prefix, ENVIRONMENT_DIR, version)
+    envdir = lang_base.environment_dir(prefix, ENVIRONMENT_DIR, version)
     with envcontext(get_env_patch(envdir)):
         yield
 
 
-def _prefix_if_file_entry(entry: list[str], prefix: Prefix) -> Sequence[str]:
-    if entry[1] == '-e':
+def _prefix_if_file_entry(
+        entry: list[str],
+        prefix: Prefix,
+        *,
+        is_local: bool,
+) -> Sequence[str]:
+    if entry[1] == '-e' or is_local:
         return entry[1:]
     else:
         return (prefix.path(entry[1]),)
@@ -73,11 +78,14 @@ def _cmd_from_hook(
         prefix: Prefix,
         entry: str,
         args: Sequence[str],
+        *,
+        is_local: bool,
 ) -> tuple[str, ...]:
     cmd = shlex.split(entry)
     _entry_validate(cmd)
 
-    return (cmd[0], *RSCRIPT_OPTS, *_prefix_if_file_entry(cmd, prefix), *args)
+    cmd_part = _prefix_if_file_entry(cmd, prefix, is_local=is_local)
+    return (cmd[0], *RSCRIPT_OPTS, *cmd_part, *args)
 
 
 def install_environment(
@@ -85,7 +93,7 @@ def install_environment(
         version: str,
         additional_dependencies: Sequence[str],
 ) -> None:
-    env_dir = helpers.environment_dir(prefix, ENVIRONMENT_DIR, version)
+    env_dir = lang_base.environment_dir(prefix, ENVIRONMENT_DIR, version)
     os.makedirs(env_dir, exist_ok=True)
     shutil.copy(prefix.path('renv.lock'), env_dir)
     shutil.copytree(prefix.path('renv'), os.path.join(env_dir, 'renv'))
@@ -153,11 +161,12 @@ def run_hook(
         args: Sequence[str],
         file_args: Sequence[str],
         *,
+        is_local: bool,
         require_serial: bool,
         color: bool,
 ) -> tuple[int, bytes]:
-    cmd = _cmd_from_hook(prefix, entry, args)
-    return helpers.run_xargs(
+    cmd = _cmd_from_hook(prefix, entry, args, is_local=is_local)
+    return lang_base.run_xargs(
         cmd,
         file_args,
         require_serial=require_serial,
