@@ -7,6 +7,7 @@ import sys
 from typing import Sequence
 
 import pre_commit.constants as C
+from pre_commit import clientlib
 from pre_commit import git
 from pre_commit.color import add_color_option
 from pre_commit.commands.autoupdate import autoupdate
@@ -52,7 +53,7 @@ def _add_config_option(parser: argparse.ArgumentParser) -> None:
 def _add_hook_type_option(parser: argparse.ArgumentParser) -> None:
     parser.add_argument(
         '-t', '--hook-type',
-        choices=C.HOOK_TYPES, action='append', dest='hook_types',
+        choices=clientlib.HOOK_TYPES, action='append', dest='hook_types',
     )
 
 
@@ -73,7 +74,10 @@ def _add_run_options(parser: argparse.ArgumentParser) -> None:
         help='When hooks fail, run `git diff` directly afterward.',
     )
     parser.add_argument(
-        '--hook-stage', choices=C.STAGES, default='commit',
+        '--hook-stage',
+        choices=clientlib.STAGES,
+        type=clientlib.transform_stage,
+        default='pre-commit',
         help='The stage during which the hook is fired.  One of %(choices)s',
     )
     parser.add_argument(
@@ -103,10 +107,35 @@ def _add_run_options(parser: argparse.ArgumentParser) -> None:
             'now checked out.'
         ),
     )
+    parser.add_argument(
+        '--pre-rebase-upstream', help=(
+            'The upstream from which the series was forked.'
+        ),
+    )
+    parser.add_argument(
+        '--pre-rebase-branch', help=(
+            'The branch being rebased, and is not set when  '
+            'rebasing the current branch.'
+        ),
+    )
     parser.add_argument(
         '--commit-msg-filename',
         help='Filename to check when running during `commit-msg`',
     )
+    parser.add_argument(
+        '--prepare-commit-message-source',
+        help=(
+            'Source of the commit message '
+            '(typically the second argument to .git/hooks/prepare-commit-msg)'
+        ),
+    )
+    parser.add_argument(
+        '--commit-object-name',
+        help=(
+            'Commit object name '
+            '(typically the third argument to .git/hooks/prepare-commit-msg)'
+        ),
+    )
     parser.add_argument(
         '--remote-name', help='Remote name used by `git push`.',
     )
@@ -141,6 +170,10 @@ def _adjust_args_and_chdir(args: argparse.Namespace) -> None:
         args.config = os.path.abspath(args.config)
     if args.command in {'run', 'try-repo'}:
         args.files = [os.path.abspath(filename) for filename in args.files]
+        if args.commit_msg_filename is not None:
+            args.commit_msg_filename = os.path.abspath(
+                args.commit_msg_filename,
+            )
     if args.command == 'try-repo' and os.path.exists(args.repo):
         args.repo = os.path.abspath(args.repo)
 
@@ -150,6 +183,10 @@ def _adjust_args_and_chdir(args: argparse.Namespace) -> None:
     args.config = os.path.relpath(args.config)
     if args.command in {'run', 'try-repo'}:
         args.files = [os.path.relpath(filename) for filename in args.files]
+        if args.commit_msg_filename is not None:
+            args.commit_msg_filename = os.path.relpath(
+                args.commit_msg_filename,
+            )
     if args.command == 'try-repo' and os.path.exists(args.repo):
         args.repo = os.path.relpath(args.repo)
 
@@ -167,11 +204,15 @@ def main(argv: Sequence[str] | None = None) -> int:
 
     subparsers = parser.add_subparsers(dest='command')
 
-    autoupdate_parser = subparsers.add_parser(
+    def _add_cmd(name: str, *, help: str) -> argparse.ArgumentParser:
+        parser = subparsers.add_parser(name, help=help)
+        add_color_option(parser)
+        return parser
+
+    autoupdate_parser = _add_cmd(
         'autoupdate',
         help="Auto-update pre-commit config to the latest repos' versions.",
     )
-    add_color_option(autoupdate_parser)
     _add_config_option(autoupdate_parser)
     autoupdate_parser.add_argument(
         '--bleeding-edge', action='store_true',
@@ -189,34 +230,17 @@ def main(argv: Sequence[str] | None = None) -> int:
         help='Only update this repository -- may be specified multiple times.',
     )
 
-    clean_parser = subparsers.add_parser(
-        'clean', help='Clean out pre-commit files.',
-    )
-    add_color_option(clean_parser)
-    _add_config_option(clean_parser)
+    _add_cmd('clean', help='Clean out pre-commit files.')
 
-    hook_impl_parser = subparsers.add_parser('hook-impl')
-    add_color_option(hook_impl_parser)
-    _add_config_option(hook_impl_parser)
-    hook_impl_parser.add_argument('--hook-type')
-    hook_impl_parser.add_argument('--hook-dir')
-    hook_impl_parser.add_argument(
-        '--skip-on-missing-config', action='store_true',
-    )
-    hook_impl_parser.add_argument(dest='rest', nargs=argparse.REMAINDER)
+    _add_cmd('gc', help='Clean unused cached repos.')
 
-    gc_parser = subparsers.add_parser('gc', help='Clean unused cached repos.')
-    add_color_option(gc_parser)
-    _add_config_option(gc_parser)
-
-    init_templatedir_parser = subparsers.add_parser(
+    init_templatedir_parser = _add_cmd(
         'init-templatedir',
         help=(
             'Install hook script in a directory intended for use with '
             '`git config init.templateDir`.'
         ),
     )
-    add_color_option(init_templatedir_parser)
     _add_config_option(init_templatedir_parser)
     init_templatedir_parser.add_argument(
         'directory', help='The directory in which to write the hook script.',
@@ -229,10 +253,7 @@ def main(argv: Sequence[str] | None = None) -> int:
     )
     _add_hook_type_option(init_templatedir_parser)
 
-    install_parser = subparsers.add_parser(
-        'install', help='Install the pre-commit script.',
-    )
-    add_color_option(install_parser)
+    install_parser = _add_cmd('install', help='Install the pre-commit script.')
     _add_config_option(install_parser)
     install_parser.add_argument(
         '-f', '--overwrite', action='store_true',
@@ -254,7 +275,7 @@ def main(argv: Sequence[str] | None = None) -> int:
         ),
     )
 
-    install_hooks_parser = subparsers.add_parser(
+    install_hooks_parser = _add_cmd(
         'install-hooks',
         help=(
             'Install hook environments for all environments in the config '
@@ -262,32 +283,24 @@ def main(argv: Sequence[str] | None = None) -> int:
             'useful.'
         ),
     )
-    add_color_option(install_hooks_parser)
     _add_config_option(install_hooks_parser)
 
-    migrate_config_parser = subparsers.add_parser(
+    migrate_config_parser = _add_cmd(
         'migrate-config',
         help='Migrate list configuration to new map configuration.',
     )
-    add_color_option(migrate_config_parser)
     _add_config_option(migrate_config_parser)
 
-    run_parser = subparsers.add_parser('run', help='Run hooks.')
-    add_color_option(run_parser)
+    run_parser = _add_cmd('run', help='Run hooks.')
     _add_config_option(run_parser)
     _add_run_options(run_parser)
 
-    sample_config_parser = subparsers.add_parser(
-        'sample-config', help=f'Produce a sample {C.CONFIG_FILE} file',
-    )
-    add_color_option(sample_config_parser)
-    _add_config_option(sample_config_parser)
+    _add_cmd('sample-config', help=f'Produce a sample {C.CONFIG_FILE} file')
 
-    try_repo_parser = subparsers.add_parser(
+    try_repo_parser = _add_cmd(
         'try-repo',
         help='Try the hooks in a repository, useful for developing new hooks.',
     )
-    add_color_option(try_repo_parser)
     _add_config_option(try_repo_parser)
     try_repo_parser.add_argument(
         'repo', help='Repository to source hooks from.',
@@ -301,32 +314,39 @@ def main(argv: Sequence[str] | None = None) -> int:
     )
     _add_run_options(try_repo_parser)
 
-    uninstall_parser = subparsers.add_parser(
+    uninstall_parser = _add_cmd(
         'uninstall', help='Uninstall the pre-commit script.',
     )
-    add_color_option(uninstall_parser)
     _add_config_option(uninstall_parser)
     _add_hook_type_option(uninstall_parser)
 
-    validate_config_parser = subparsers.add_parser(
+    validate_config_parser = _add_cmd(
         'validate-config', help='Validate .pre-commit-config.yaml files',
     )
-    add_color_option(validate_config_parser)
-    _add_config_option(validate_config_parser)
     validate_config_parser.add_argument('filenames', nargs='*')
 
-    validate_manifest_parser = subparsers.add_parser(
+    validate_manifest_parser = _add_cmd(
         'validate-manifest', help='Validate .pre-commit-hooks.yaml files',
     )
-    add_color_option(validate_manifest_parser)
-    _add_config_option(validate_manifest_parser)
     validate_manifest_parser.add_argument('filenames', nargs='*')
 
+    # does not use `_add_cmd` because it doesn't use `--color`
     help = subparsers.add_parser(
         'help', help='Show help for a specific command.',
     )
     help.add_argument('help_cmd', nargs='?', help='Command to show help for.')
 
+    # not intended for users to call this directly
+    hook_impl_parser = subparsers.add_parser('hook-impl')
+    add_color_option(hook_impl_parser)
+    _add_config_option(hook_impl_parser)
+    hook_impl_parser.add_argument('--hook-type')
+    hook_impl_parser.add_argument('--hook-dir')
+    hook_impl_parser.add_argument(
+        '--skip-on-missing-config', action='store_true',
+    )
+    hook_impl_parser.add_argument(dest='rest', nargs=argparse.REMAINDER)
+
     # argparse doesn't really provide a way to use a `default` subparser
     if len(argv) == 0:
         argv = ['run']
@@ -340,11 +360,11 @@ def main(argv: Sequence[str] | None = None) -> int:
     with error_handler(), logging_handler(args.color):
         git.check_for_cygwin_mismatch()
 
+        store = Store()
+
         if args.command not in COMMANDS_NO_GIT:
             _adjust_args_and_chdir(args)
-
-        store = Store()
-        store.mark_config_used(args.config)
+            store.mark_config_used(args.config)
 
         if args.command == 'autoupdate':
             return autoupdate(
